@@ -15,7 +15,7 @@ use CSS::Watcher::Parser;
 use CSS::Watcher::ParserLess;
 use CSS::Watcher::Monitor;
 
-our $VERSION = '0.3.1';
+our $VERSION = '0.3.2';
 
 use constant DEFAULT_HTML_STUFF_DIR => '~/.emacs.d/ac-html-csswatcher/completion/';
 
@@ -46,6 +46,12 @@ sub update {
 
         my (@ignore, @allow);
         my $cfg = path($proj_dir)->child('.csswatcher');
+
+        # clear project cache if .csswatcher changed
+        if ($prj->{monitor}->is_changed($cfg)) {
+            $prj->{monitor}->make_dirty();
+        }
+
         if (-f $cfg) {
             if (open (CFG, '<:encoding(UTF-8)', $cfg)) {
                 while (<CFG>) {
@@ -57,7 +63,6 @@ sub update {
             }
         }
 
-
         # scan new or changed files, cache them
         my $changes = 0;
         $prj->{monitor}->scan (
